InvalidPersistentAccessHandleException class final

A stored handle is structurally malformed and cannot become usable later.

Backends should not use this for disconnected volumes, missing paths, permission errors, or other conditions that may be temporary.

Implemented types

Constructors

InvalidPersistentAccessHandleException(String message)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited