legacyHandleKind property
The kind assigned to untagged bookmarks written by an older application.
Implementation
final PersistentAccessEntityKind? legacyHandleKind;
The kind assigned to untagged bookmarks written by an older application.
final PersistentAccessEntityKind? legacyHandleKind;