describeHandle method

PersistentAccessHandleDescription describeHandle(
  1. String handle
)

Returns metadata encoded in handle without resolving filesystem access.

This method may throw an error recognized by isInvalidHandleError.

Implementation

PersistentAccessHandleDescription describeHandle(final String handle) {
  return const PersistentAccessHandleDescription();
}