PersistentAccessHandleDescription class final

Non-secret metadata that a backend can recover without opening a handle.

Constructors

PersistentAccessHandleDescription({PersistentAccessEntityKind? kind, String? lastKnownPath})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → PersistentAccessEntityKind?
final
lastKnownPath → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited