UnsupportedPersistentAccessHandleException class final

A stored handle uses a backend or schema version this package cannot read.

Unlike InvalidPersistentAccessHandleException, this does not prove that the stored value is malformed. Collections retain the handle so it can be recovered after the application adds the corresponding backend or upgrades to a package version that understands its schema.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited