remove method
Removes the available item matching entity's backend identity and kind.
Available move-following handles and apparent path-based matches are revalidated first because a handle may have followed a moved item since the latest snapshot. Returns false when the collection has no matching available item after revalidation.
Implementation
Future<bool> remove(final FileSystemEntity entity) {
entityKindOf(entity);
return _serializeOperation(() => _removeEntity(entity));
}