removeEntry method
Removes entry by its public identifier, including when it is unavailable.
Returns false when the identifier is no longer stored.
Implementation
Future<bool> removeEntry(final PersistentAccessEntry entry) {
return removeById(entry.id);
}