MacOSPersistentAccessBackend class final

macOS persistent access implemented with bounded security-scoped operations.

Inheritance

Properties

fixedEntityKind PersistentAccessEntityKind?
When non-null, the backend accepts only this entity kind.
final
handlesFollowMoves bool
Whether an available handle can follow its entity to a new identity.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
legacyHandleKind PersistentAccessEntityKind?
The kind assigned to untagged bookmarks written by an older application.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createHandle(FileSystemEntity entity) Future<String>
Creates an opaque persistent handle for an authorized entity.
override
describeHandle(String handle) PersistentAccessHandleDescription
Returns metadata encoded in handle without resolving filesystem access.
override
descriptionIdentity(PersistentAccessHandleDescription description) String?
Returns a stable identity for metadata recovered from a stored handle.
inherited
entityIdentity(FileSystemEntity entity) String
Returns a stable identity used to reject duplicate entities.
inherited
isInvalidHandleError(Object error) bool
Whether error proves that the serialized handle is permanently invalid.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withHandleAccess<T>(String handle, FutureOr<T> operation(FileSystemEntity entity)) Future<T>
Runs operation with access to the file or directory stored by handle.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited