isInvalidHandleError method

  1. @override
bool isInvalidHandleError(
  1. Object error
)
override

Whether error proves that the serialized handle is permanently invalid.

Return false for uncertain and temporary failures. If classification itself throws, the collection preserves the handle.

Implementation

@override
bool isInvalidHandleError(final Object error) {
  if (super.isInvalidHandleError(error) || error is FormatException) {
    return true;
  }
  if (error is! PlatformException) {
    return false;
  }
  if (error.code == 'InvalidArguments' || error.code == 'InvalidBookmark') {
    return true;
  }
  return _isCorruptBookmarkError(error);
}