PersistentAccessBackend class abstract

Platform-specific creation, recovery, and lifecycle behavior.

A handle is opaque to PersistentFileAccessSet. Implementations may store a security capability, a path, or another stable serialized identifier.

Implementers

Constructors

PersistentAccessBackend()
const

Properties

handlesFollowMoves bool
Whether an available handle can follow its entity to a new identity.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createHandle(FileSystemEntity entity) Future<String>
Creates an opaque persistent handle for an authorized entity.
describeHandle(String handle) PersistentAccessHandleDescription
Returns metadata encoded in handle without resolving filesystem access.
descriptionIdentity(PersistentAccessHandleDescription description) String?
Returns a stable identity for metadata recovered from a stored handle.
entityIdentity(FileSystemEntity entity) String
Returns a stable identity used to reject duplicate entities.
isInvalidHandleError(Object error) bool
Whether error proves that the serialized handle is permanently invalid.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withHandleAccess<T>(String handle, FutureOr<T> operation(FileSystemEntity entity)) Future<T>
Runs operation with access to the file or directory stored by handle.

Operators

operator ==(Object other) bool
The equality operator.
inherited